Documentation
¶
Overview ¶
Package fssyscall abstracts syscall file descriptors across platform.Handles
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FLockEx ¶ added in v0.5.2
FLockEx attempts to create an advisory exclusive lock on the file associated to the given *os.File.
func FTryLockEx ¶ added in v0.5.2
FTryLockEx attempts to create an advisory exclusive lock on the file associated to the given *os.File without blocking. Returns an error if the lock cannot be acquired immediately.
func FUnlockEx ¶ added in v0.5.2
FUnlockEx releases an advisory lock on the file associated with the given *os.File.
func LockEx ¶
LockEx attempts to create an advisory exclusive lock on the file associated to the given Handle.
Types ¶
type Handle ¶
type Handle int
Handle represents a OS specific file descriptor
func Open ¶
Open performs syscall.Open returning a Handle
Click to show internal directories.
Click to hide internal directories.